from dataclasses import dataclass
from datetime import datetime

from psycopg import sql
from psycopg.rows import class_row
from psycopg_pool import AsyncConnectionPool


@dataclass
class Member:
    id: int
    email: str
    password_hash: str
    created: datetime
    email_verified: datetime | None


async def select_member_by_email(db: AsyncConnectionPool, email: str) -> Member | None:
    """
    Find exactly one email match in users list in PostgreSQL database
    """
    async with db.connection() as conn:
        async with conn.cursor(row_factory=class_row(Member)) as curr:
            query = sql.SQL(
                """
                    SELECT id, email, password_hash, created, email_verified
                        FROM members
                        WHERE LOWER(email) = LOWER(%s);
                    """
            )

            await curr.execute(query, (email,))

            print(query.as_string(conn))

            member = await curr.fetchone()

            return None if member is None else member
